<?php
/*
Plugin Name:  PDB LDV light
Plugin URI:   https://www.eraclito.it/applicazioni-web/poste-delivery-business-integrazione-woocommerce/
Description:  Poste Delivery Business. Generazione delle lettere di vettura - demo version
Version:      1.3.6
Author:       Eraclito - Alessio Rosi 
Author URI:   https://www.eraclito.it
License:      GPL2
License URI:  https://www.gnu.org/licenses/gpl-2.0.html
Text Domain:  wporg
Domain Path:  /languages
*/

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) { exit; }
define('TKDS_SHIPPING_VERSION', '1.0');
define('TKDS_SHIPPING_URL', plugin_dir_url(__FILE__));
define('TKDS_SHIPPING_DIRECTORY', dirname( __FILE__ ));


// register_activation
function tkds_shipping_activation() {
   

}
register_activation_hook(__FILE__, 'tkds_shipping_activation');

// register_deactivation
function tkds_shipping_deactivation() {
 
}
register_deactivation_hook(__FILE__, 'tkds_shipping_deactivation');


// Enqueue styles & scripts
function tkds_shipping_enqueue() {
    // Register Styles
    wp_enqueue_style( 'tkds-shipping-google-font', 'https://fonts.googleapis.com/css?family=Crete+Round|Dancing+Script|Noto+Serif:400,700&display=swap' );
    wp_register_style( 'tkds-shipping-style', TKDS_SHIPPING_URL . 'inc/theme/css/style.css', null, TKDS_SHIPPING_VERSION );

    // Register Scripts
    wp_register_script( 'tkds-shipping-ajax-script', TKDS_SHIPPING_URL . 'inc/theme/js/ajax.js', array('jquery'), TKDS_SHIPPING_VERSION );
    wp_localize_script( 'tkds-shipping-ajax-script', 'tkds_shipping_ajax_object',   array( 'tkds_shipping_ajax_url' => admin_url( 'admin-ajax.php' ) ) );
    wp_register_script( 'tkds-shipping-canvas-1-script', "https://cdnjs.cloudflare.com/ajax/libs/html2canvas/0.4.1/html2canvas.min.js", array('jquery'), TKDS_SHIPPING_VERSION );
    wp_enqueue_script( 'tkds-shipping-ajax-script' );
    wp_enqueue_script( 'tkds-shipping-canvas-1-script' );
    wp_enqueue_style( 'tkds-shipping-style' );
}
add_action( 'wp_enqueue_scripts', 'tkds_shipping_enqueue' );


// Ajax handler function
add_action( 'wp_ajax_tkds_shipping_action', 'tkds_shipping_action' );
add_action( 'wp_ajax_nopriv_tkds_shipping_action', 'tkds_shipping_action' );



// includes
include_once TKDS_SHIPPING_DIRECTORY . '/inc/theme/theme.php';
include_once TKDS_SHIPPING_DIRECTORY . '/inc/theme/constant.php';
include_once TKDS_SHIPPING_DIRECTORY . '/inc/theme/api/api.php';








/**
 * Adds 'LDV' column header to 'Orders' page immediately after 'Status' column.
 *
 * @param string[] $columns
 * @return string[] $new_columns
 */
function wc_ldv_column( $columns ) {

    $reordered_columns = array();

    foreach ( $columns as $key => $column ) {

        $reordered_columns[$key] = $column;

        if( $key ==  'order_status' ){
            $reordered_columns['ldv'] = __( 'LDV','theme_domain');
        }
    }

    return $reordered_columns;
}
add_filter( 'manage_edit-shop_order_columns', 'wc_ldv_column', 20 );



// Adding custom fields meta data LDV
add_action( 'manage_shop_order_posts_custom_column' , 'custom_orders_list_column_content', 20, 2 );
function custom_orders_list_column_content( $column, $post_id )
{

    if ( $column=='ldv') {
        // Get ldv post meta data
            $order = wc_get_order($post_id);
            $download_link = get_post_meta( $post_id, '_pdb_waybill_link', true );
         
            $ldv=get_post_meta( $post_id, '_pdb_waybill_code', true );
            

            if(!empty($download_link)){
                if ($download_link=='external'){
                    //echo "<a href='#' class='btn btn-default download_button'><img class='btn btn-default download_button'  src='". plugin_dir_url( __FILE__ )."inc/theme/img/waybill-blu.jpg' width='30' height='30' title='LDV esterna N°".$ldv."'>";
                    echo "<mark  style='vertical-align:super;margin-right:5px' class='order-status status-processing tips' data-tip='LDV esterna N°".$ldv."'><span><a href='#'><img style='vertical-align:middle;' src='". plugin_dir_url( __FILE__ )."inc/theme/img/waybill-blu.png' width='30' height='30'></a></span></mark>";

                } else {
                   echo "<mark  style='vertical-align:super;margin-right:5px' class='order-status status-processing tips' data-tip='Scarica LDV N°".$ldv."'><span><a href='".$download_link."' target='_blank' ><img style='vertical-align:middle;' src='". plugin_dir_url( __FILE__ )."/inc/theme/img/waybill-yellow.png' width='30' height='30'></a></span></mark>";
                }
                if ($order->has_status( 'completed' )){
                echo "<mark  style='vertical-align:super;' class='order-status status-completed tips' data-tip='Traccia il pacco N°".$ldv." <br />sul sito di Poste Italiane'><span><a href='https://business.poste.it/professionisti-imprese/cerca/index.html#!/risultati-spedizioni/".$ldv."' target='_blank' ><img style='vertical-align:middle;' src='". plugin_dir_url( __FILE__ )."/inc/theme/img/package-tracker.png' width='30' height='30'></a></span></mark>";            
                }
            }
            else
                echo '<small>(<em>nessuna LDV</em>)</small>'; 

    }
    
}



// add metabox to order

add_action( "add_meta_boxes", "add_meta_boxes" );

function add_meta_boxes()
{

    $order_id=$_GET['post'];

    
        add_meta_box(
            "woocommerce-order-my-custom",
            __( "Spedizione PDB" ),
            "order_my_custom",
            "shop_order",
            "side",
            "default"
        );
}

function curl_post_request($url, $post, $headers)
{
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_POST, 1);
    curl_setopt($ch, CURLOPT_POSTFIELDS, $post);
    curl_setopt($ch, CURLOPT_HTTPHEADER, $headers);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, TRUE);
    curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 0);
    curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);

    $response = curl_exec($ch);
    curl_close($ch);

    return $response;
    
}

function order_my_custom()
{
    global $woocommerce,$wpdb;
    $post_id=$_GET['post'];
    
    $order_id=$_GET['post'];

    $order = new WC_Order( $order_id );
    ?>

    <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.7/css/bootstrap.min.css">
    <link rel="stylesheet" href="<?php echo plugin_dir_url( __FILE__ ); ?>/inc/theme/css/style.css">
    <style type="text/css">
            .popup-outer {
                max-width: 600px;
            }
            .error_msg{
                color:red;
            }
            .loader{
              background-color: #000;
              display: none;
              height: 100%;
              left: 0;
              top: 0;
              opacity: 0.2;
              position: fixed;
              right: 0;
              width: 100%;
              z-index: 99999;
            }

            .loader .d-flex {
              align-items: center;
              display: flex;
              height: 100%;
              justify-content: center;
            }

            .loader img {
              max-width: 150px;
              width: 100%;
            }
            .download_button img {
                vertical-align: middle;
                width: 30px;
                margin-top: -6px;
                margin-left: 6px;
            }

            .popup-close {
                color: #FFFFFF;
            }

            header.popup-header {
                background-color: #5bc0de;
                padding: 5px 20px !important;
            }

            header h3 {
                color: #FFFFFF;
            }
        </style>

           
            



            <!-- Pop up for LDV request -->


            <div id="popup_01" class="popup-wrap">
              <div class="popup-overlay"></div>
               <div class="extra-wrap">
                <div class="extra-inner">
                <div class="popup-outer">
                <div class="popup-box">
                  <header class="popup-header"> <a class="popup-close" href="javascript:void(0);">×</a>
                <h3>Richiesta Lettera di Vettura</h3>
                </header>
                <div class="popup-scroll">
                <div class="popup-body">
                <form class="row" action="" method="post">
                  <input type="hidden" name="order_id" value="<?php echo $post_id; ?>">
                  <div class="col-md-6">
                      <label>Tipologia pacco</label>
                      
                      <select class="tkds_pkg_id form-control" name="pkg_id">
                        
                        <option value="Small">Small</option>
                      </select>
                  </div>
                  <div class="col-md-6">
                      
                      <label>Peso dei prodotti (grammi) </label>

                      <input type="number" name="weight" class="form-control tkds_weight" step="10" value="100">
                      <i><small>(inserisci il peso dei prodotti cliccando il pulsante sottostante oppure lascia il peso predefinito)</small></i><br />
                      
                  </div>
                  <br>
                  <div class="col-md-6">
                      <label>Contenuto del pacco</label>
                      <?php $default_content=get_option('tkds_contentvalue')==''?'Merchandising':get_option('tkds_contentvalue'); ?>
                      <input type="text" name="tkds_content" class="form-control tkds_content" placeholder="Descrizione contenuto (max 40)" value="<?php echo $default_content; ?>">
                  </div>
                  <div class="col-md-6">
                      <label>Calcola pesi</label>
                      <button type="button" class="btn btn-warning calcola_peso">Calcola il peso dei prodotti</a>
                  </div>

                  <div class="col-md-12">
                    <br>
                    <button type="button" name="ship_to_pdb_event" class="btn btn-info ship_to_pdb_event" value="Ship to PDB">Invia richesta LDV</button>
                    <br>
                    <span class="error_msg"></span>
                    <br>
                    <br>
                  </div>
                </form>
                </div>
                </div>
                </div>
                </div>
               </div>
              </div>
           </div>
         <!--     END Pop up for LDV request -->


<!-- Pop up per inserire la LDV esterna -->
            
            <div id="popup_02" class="popup-wrap">
              <div class="popup-overlay"></div>
               <div class="extra-wrap">
                <div class="extra-inner">
                <div class="popup-outer">
                <div class="popup-box">
                  <header class="popup-header"> <a class="popup-close" href="javascript:void(0);">×</a>
                <h3>Inserimento Lettera di Vettura esterna</h3>
                </header>
                <div class="popup-scroll">
                <div class="popup-body">
                <form class="row" action="" method="post">
                  <input type="hidden" name="order_id" value="<?php echo $post_id; ?>">
                  <div class="col-md-6">
                      <label>N° Lettera di vettura</label>
                      <input type="text" name="nldv" class="form-control tkds_nldv"  value="">
                  </div>
                  
                  <br>
                  <div class="col-md-12">
                    <br>
                    <button type="button" name="insert_ldv_event" class="btn btn-info insert_ldv_event" value="Insert LDV">Inserisci LDV</button>
                    <br>
                    <span class="error_msg"></span>
                    <br>
                  </div>
                </form>
                </div>
                </div>
                </div>
                </div>
               </div>
              </div>
            </div>

            <!-- Fine Pop up per inserire la LDV esterna -->





             <!-- Pop up delete LDV  -->
            
             <div id="popup_03" class="popup-wrap">
              <div class="popup-overlay"></div>
               <div class="extra-wrap">
                <div class="extra-inner">
                <div class="popup-outer">
                <div class="popup-box">
                  <header class="popup-header"> <a class="popup-close" href="javascript:void(0);">×</a>
                <h3>Cancella Lettera di Vettura</h3>
                </header>
                <div class="popup-scroll">
                <div class="popup-body">
                <form class="row" action="" method="post">
                  <input type="hidden" name="order_id" value="<?php echo $post_id; ?>">
                  <div class="col-md-12">
                      <br>
                      <p style="font-size:15px;">Vuoi veramente cancellare la lettera di vettura <strong><?php echo get_post_meta( $post_id, '_pdb_waybill_code', true )?></strong> per l'ordine N°<strong><?php echo $post_id; ?></strong>?</p>
                      <?php 
                    
                      if ($order->has_status( 'completed' )) {
                          
                          echo '<p style="font-size:15px; color:red;">ATTENZIONE: lo stato dell\' ordine è <span style="text-decoration: underline;">COMPLETATO</span>! Il cliente può già traccare il pacco sulla sua dashboard. Controlla che il pacco non sia già partito!</p>';
                      }
                      ?>
                      <p style="font-size:10px;">La cencellazione della lettera di vettura permetterà di richiederne una nuova per evadere questo ordine. La lettera di vettura cancellata rimarrà nei sistemi di Poste Italiane ma non verrà mai utilizzata. Verrà elimiata automaticamente dai sitemi di Poste Otaliane dopo un tempo determinato </p>  
                    </div>
                  
                  <br>
                  <div class="col-md-12">
                    <br>
                    <button type="button" name="cancel_ldv_event" class="btn btn-info cancel_ldv_event" value="Cancella LDV">Cancella LDV</button>
                    <!--<button type="button" name="cancel_ldv" class="btn btn-info popup-close-cancel" value="Annulla">Annulla</button> -->
                    <br>
                    <span class="error_msg"></span>
                  </div>
                </form>
                </div>
                </div>
                </div>
                </div>
               </div>
              </div>
            </div>

            <!-- Fine Pop up delete LDV  -->



            <div class="loader">
              <div class="d-flex">
              <img src="<?php echo plugin_dir_url( __FILE__ ); ?>/inc/theme/img/loader.gif" class="loader-img" />
              </div>
            </div>






<?php
    
   
     if( ($order->has_status( 'processing' )||$order->has_status( 'completed' )) && (! $order->has_shipping_method('local_pickup')) ) {
        $download_link = get_post_meta( $post_id, '_pdb_waybill_link', true );
        ?>

        <?php
        echo "<div class='download_block'>";
        
        
        
        $ldv=get_post_meta( $post_id, '_pdb_waybill_code', true );
        if(!empty($download_link)){

            if ($download_link=='external') {
                echo "<mark  style='vertical-align:super;margin-right:5px' class='order-status status-processing tips' data-tip='LDV esterna N°".$ldv."'><span><a href='#'><img style='vertical-align:middle;' src='". plugin_dir_url( __FILE__ )."inc/theme/img/waybill-blu.png' width='30' height='30'></a></span></mark>";
                echo "<mark  style='vertical-align:super;margin-right:5px' class='order-status status-processing tips cancel_ldv' data-tip='Cancella LdV N°".$ldv."'><span><img style='vertical-align:middle;' src='". plugin_dir_url( __FILE__ )."inc/theme/img/waybill-delete.png' width='30' height='30'></span></mark>";

            } else {
                echo "<mark  style='vertical-align:super;margin-right:5px' class='order-status status-processing tips' data-tip='Scarica LDV N°".$ldv."'><span><a href='".$download_link."' target='_blank' ><img style='vertical-align:middle;' src='". plugin_dir_url( __FILE__ )."/inc/theme/img/waybill-yellow.png' width='30' height='30'></a></span></mark>";
                echo "<mark  style='vertical-align:super;margin-right:5px' class='order-status status-processing tips cancel_ldv' data-tip='Cancella LdV N°".$ldv."'><span class='cancel_ldv'><img style='vertical-align:middle;' src='". plugin_dir_url( __FILE__ )."inc/theme/img/waybill-delete.png' width='30' height='30'></span></mark>";
                //echo "<button type='button' class='btn btn-danger cancel_ldv'>Cancella LDV</button>";
            }
            
            if ($order->has_status( 'completed' )){
               echo "<mark  style='vertical-align:super;' class='order-status status-completed tips' data-tip='Traccia il pacco N°".$ldv." <br />sul sito di Poste Italiane'><span><a href='https://business.poste.it/professionisti-imprese/cerca/index.html#!/risultati-spedizioni/".$ldv."' target='_blank' ><img style='vertical-align:middle;' src='". plugin_dir_url( __FILE__ )."/inc/theme/img/package-tracker.png' width='30' height='30'></a></span></mark>";            
            }
  
        }
        else
        {

            
            
               $url="https://apid.gp.posteitaliane.it/dev/kindergarden/user/sessions";
                $scope="api://8f0f2c58-19a8-45ef-9f9e-8bcb0acc7657/.default";
				$clientId="611c9cb0-deff-44b8-8337-b5fe2b3297fc";
                $secretId="aSn8Q~5LbgHtdwqr~DYJ14z5UBTowLBqMPMonbG.";

			

            $headers = [
            'POSTE_clientID: 611c9cb0-deff-44b8-8337-b5fe2b3297fc'
            ];
            $post='{
                "clientId": "611c9cb0-deff-44b8-8337-b5fe2b3297fc",
                "secretId": "aSn8Q~5LbgHtdwqr~DYJ14z5UBTowLBqMPMonbG.",
                "scope": "'.$scope.'",
                "grantType": "client_credentials"
                }';
            $result['response']=curl_post_request($url, $post, $headers);
            $result=json_decode($result['response']);
            ?>

  
           
                <button type="button" class="btn btn-info ship_to_pdb">Richiedi LDV</button>
                <button type="button" class="btn btn-info insert_ldv">Inserisci LDV</button>
                
         

           


            <?php
        }
        echo "</div>";
    } else {
		 echo "<div class='download_block'>";
         
        echo "<p>Lo ststo dell'ordine o il metodo di spedizione, non permettono la richiesta della lettere di vettura";
		echo "</div>";
	}



?>



<script>
jQuery(document).ready(function($) {
    var order_id=<?php echo $post_id; ?>;

    $('.cancel_ldv').on('click',function(){
        
        
        $('#popup_03').fadeIn();
        //$('.ship_to_pdb').attr('disabled','disabled');
        //$('.insert_ldv').attr('disabled','disabled');
        $('.error_msg').html('');
    });


    $('.insert_ldv').on('click',function(){
        $('#popup_02').fadeIn();
        $('.ship_to_pdb').attr('disabled','disabled');
        $('.insert_ldv').attr('disabled','disabled');
        $('.error_msg').html('');
    });

    $('.ship_to_pdb').on('click',function(){
        console.log('genera');
        $('#popup_01').fadeIn();
        $('.ship_to_pdb').attr('disabled','disabled');
        $('.insert_ldv').attr('disabled','disabled');
        $('.error_msg').html('');
    });
    

    $('.popup-close').on('click', function() {
      $(this).closest('.popup-wrap').fadeOut();
      $('.ship_to_pdb').removeAttr('disabled');
      $('.insert_ldv').removeAttr('disabled');

     });




    //js Events


    $('.insert_ldv_event').on('click',function(){
        $('.loader').fadeIn();
        $('.insert_ldv_event').attr('disabled','disabled');

        var nldv=$('.tkds_nldv').val();
        

        $.ajax({
             type : "POST",
             dataType : "json",
             url : "/wp-admin/admin-ajax.php",
             data : {action: "tkds_shipping_action",id:order_id,n_ldv:nldv,mode:'ildv'},
             success: function(response) {
                   
                $('#popup_02').closest('.popup-wrap').fadeOut();

                   //$(this).closest('.popup-wrap').fadeOut();
                   $('.loader').fadeOut();
                   if(nldv!=null)
                        //$('.download_block').html("<mark style='vertical-align:super;margin-right:5px' class='order-status status-processing tips' data-tip='LDV esterna N°"+$nldv+"'><span><img style='vertical-align:middle;' src='<?php echo plugin_dir_url( __FILE__ );?>inc/theme/img/waybill-blu.png' width='30' height='30'></span></mark>");

                        //$('.download_block').html("<a href='#' class='btn btn-default download_button' target='_blank'>LDV N°"+nldv+" <img src='<?php echo plugin_dir_url( __FILE__ );?>/inc/theme/img/waybill-blu.jpg' width='30' height='30'></a>");
                        $('.download_block').html("<button class='btn btn-default download_button'>LDV N°"+nldv+" <img src='<?php echo plugin_dir_url( __FILE__ );?>/inc/theme/img/waybill-blu.jpg' width='30' height='30'></button>");

                    else{
                        var result=response.result.result;
                        $('.error_msg').html(result.errorDescription);
                        $('.ship_to_pdb').removeAttr('disabled');
                        $('.ship_to_pdb_event').removeAttr('disabled');
                    }
            }
        });


    });

    $('.ship_to_pdb_event').on('click',function(){
                        $('.loader').fadeIn();
                        $('.ship_to_pdb_event').attr('disabled','disabled');
                        
                        var weight=$('.tkds_weight').val();
                        var content=$('.tkds_content').val();

                        $.ajax({
                             type : "POST",
                             dataType : "json",
                             url : "/wp-admin/admin-ajax.php",
                             data : {action: "tkds_shipping_action",id:order_id,access_token:'<?php echo $result->access_token; ?>',weight:weight,content:content,mode:'rpdb'},
                             success: function(response) {
                                   //$(this).closest('.popup-wrap').fadeOut();
                                   $('#popup_01').closest('.popup-wrap').fadeOut();
                                //   console.log(access_token);
                                    console.log(response);
                                   $('.loader').fadeOut();
                                   if(response.download_link!=null)
                                    $('.download_block').html("<a href='"+response.download_link+"' class='btn btn-default download_button' target='_blank'>Scarica LDV <img src='<?php echo plugin_dir_url( __FILE__ );?>/inc/theme/img/waybill-yellow.jpg' width='30' height='30'></a>");
                                    else{
                                        var result=response.result.result;
                                        $('.error_msg').html(result.errorDescription);
                                        $('.ship_to_pdb').removeAttr('disabled');
                                        $('.ship_to_pdb_event').removeAttr('disabled');
                                    }
                            }
                        });
    });



    // calcola, a richiesta, il peso dei prodotti

    $('.calcola_peso').on('click',function(){
        
        <?php
        $order_items = $order->get_items();
        $tot_p_weight=0;
        foreach( $order_items as $item ) {
            $p_weight=0;
            $p_quantity=$item->get_quantity();
            $product = wc_get_product( $item['product_id'] );
            if ( $product->has_weight() ) {
                $p_weight=$product->get_weight() ? wc_format_decimal($product->get_weight(), 2) : '0';
                $p_weight=$product->get_weight() * $p_quantity;
            }
            $tot_p_weight=$tot_p_weight + $p_weight;
            
        }

        $tot_p_weight=$tot_p_weight*1000; // il peso va espresso in grammi
        
    ?>

        $('.tkds_weight').val(<?php echo $tot_p_weight?>);
        
    })





    $('.cancel_ldv_event').on('click',function(){
        $('.loader').fadeIn();
        $.ajax({
             type : "POST",
             dataType : "json",
             url : "/wp-admin/admin-ajax.php",
             data : {action: "tkds_shipping_action",id:order_id,mode:'cancel-ldv'},
             success: function(response) {
                   
                   
                   $('#popup_03').closest('.popup-wrap').fadeOut();
                   
                   $('.download_block').html('<h5>Sto cancellando la lattera di vettura ....</h5>');
                   location.reload(true);
                   $('.loader').fadeOut();
                    
            }
        });


    });

});
</script>






<?php



}


?>